package cn.iocoder.yudao.module.jx.service;

import cn.iocoder.yudao.module.jx.domain.DriveSchoolContract;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

import java.util.List;

/**
 * 驾校合同Service接口
 *
 * @author ruoyi
 * @date 2024-05-25
 */
public interface IDriveSchoolContractService
{
    /**
     * 查询驾校合同
     *
     * @param id 驾校合同主键
     * @return 驾校合同
     */
    public DriveSchoolContract selectDriveSchoolContractById(Long id);

    /**
     * 查询驾校合同列表
     *
     * @param driveSchoolContract 驾校合同
     * @return 驾校合同集合
     */
    public IPage<DriveSchoolContract> selectDriveSchoolContractList(DriveSchoolContract driveSchoolContract, Page<DriveSchoolContract> page);

    /**
     * 新增驾校合同
     *
     * @param driveSchoolContract 驾校合同
     * @return 结果
     */
    public int insertDriveSchoolContract(DriveSchoolContract driveSchoolContract);

    /**
     * 修改驾校合同
     *
     * @param driveSchoolContract 驾校合同
     * @return 结果
     */
    public int updateDriveSchoolContract(DriveSchoolContract driveSchoolContract);

    /**
     * 批量删除驾校合同
     *
     * @param ids 需要删除的驾校合同主键集合
     * @return 结果
     */
    public int deleteDriveSchoolContractByIds(Long[] ids);

    /**
     * 删除驾校合同信息
     *
     * @param id 驾校合同主键
     * @return 结果
     */
    public int deleteDriveSchoolContractById(Long id);
}
